@@ -486,6 +486,13 @@ AddOption(
     help='Show pystatacons configuration.',
 )
 
+AddOption(
+    '--show-specialsig',
+    dest='show_specialsig',
+    action='store_true',
+    default=False,
+    help='Show special content signature calculations.',
+)
 
 ##############################################
 #              Patching                      #
@@ -559,7 +566,7 @@ def hash_file_signature_new(fname, chunksize=65536, hash_format=None):
     if fname_ext in special_sig_fns.keys():
         try:
             sig = special_sig_fns[fname_ext](fname)
-            if "explain" in GetOption("debug"):
+            if GetOption("show_specialsig"):
                 print_during_build('Computed ' + fname_ext[1:] + '-signature: ' + fname + "\n")
             return sig
         except Exception as e:
